@@ -117,8 +117,25 @@ import aws_cdk.aws_lambda_event_sources
 import aws_cdk.core
 
 
-class DynamoDBStreamToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda.DynamoDBStreamToLambda"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, deploy_lambda: bool, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+class DynamoDBStreamToLambda(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda.DynamoDBStreamToLambda",
+):
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        deploy_lambda: bool,
+        dynamo_event_source_props: typing.Optional[
+            aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
+        ] = None,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -136,7 +153,14 @@ class DynamoDBStreamToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, js
         summary:
         :summary:: Constructs a new instance of the LambdaToDynamoDB class.
         """
-        props = DynamoDBStreamToLambdaProps(deploy_lambda=deploy_lambda, dynamo_event_source_props=dynamo_event_source_props, dynamo_table_props=dynamo_table_props, existing_lambda_obj=existing_lambda_obj, existing_table_obj=existing_table_obj, lambda_function_props=lambda_function_props)
+        props = DynamoDBStreamToLambdaProps(
+            deploy_lambda=deploy_lambda,
+            dynamo_event_source_props=dynamo_event_source_props,
+            dynamo_table_props=dynamo_table_props,
+            existing_lambda_obj=existing_lambda_obj,
+            existing_table_obj=existing_table_obj,
+            lambda_function_props=lambda_function_props,
+        )
 
         jsii.create(DynamoDBStreamToLambda, self, [scope, id, props])
 
@@ -151,9 +175,31 @@ class DynamoDBStreamToLambda(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, js
         return jsii.get(self, "lambdaFunction")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda.DynamoDBStreamToLambdaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'dynamo_event_source_props': 'dynamoEventSourceProps', 'dynamo_table_props': 'dynamoTableProps', 'existing_lambda_obj': 'existingLambdaObj', 'existing_table_obj': 'existingTableObj', 'lambda_function_props': 'lambdaFunctionProps'})
-class DynamoDBStreamToLambdaProps():
-    def __init__(self, *, deploy_lambda: bool, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-dynamodb-stream-lambda.DynamoDBStreamToLambdaProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "deploy_lambda": "deployLambda",
+        "dynamo_event_source_props": "dynamoEventSourceProps",
+        "dynamo_table_props": "dynamoTableProps",
+        "existing_lambda_obj": "existingLambdaObj",
+        "existing_table_obj": "existingTableObj",
+        "lambda_function_props": "lambdaFunctionProps",
+    },
+)
+class DynamoDBStreamToLambdaProps:
+    def __init__(
+        self,
+        *,
+        deploy_lambda: bool,
+        dynamo_event_source_props: typing.Optional[
+            aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
+        ] = None,
+        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
+        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+    ) -> None:
         """
         :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param dynamo_event_source_props: Optional user provided props to override the default props. Default: - Default props are used
@@ -165,17 +211,29 @@ class DynamoDBStreamToLambdaProps():
         summary:
         :summary:: The properties for the DynamoDBStreamToLambda Construct
         """
-        if isinstance(dynamo_event_source_props, dict): dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(**dynamo_event_source_props)
-        if isinstance(dynamo_table_props, dict): dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
-        if isinstance(lambda_function_props, dict): lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(dynamo_event_source_props, dict):
+            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(
+                **dynamo_event_source_props
+            )
+        if isinstance(dynamo_table_props, dict):
+            dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
+        if isinstance(lambda_function_props, dict):
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
+                **lambda_function_props
+            )
         self._values = {
-            'deploy_lambda': deploy_lambda,
+            "deploy_lambda": deploy_lambda,
         }
-        if dynamo_event_source_props is not None: self._values["dynamo_event_source_props"] = dynamo_event_source_props
-        if dynamo_table_props is not None: self._values["dynamo_table_props"] = dynamo_table_props
-        if existing_lambda_obj is not None: self._values["existing_lambda_obj"] = existing_lambda_obj
-        if existing_table_obj is not None: self._values["existing_table_obj"] = existing_table_obj
-        if lambda_function_props is not None: self._values["lambda_function_props"] = lambda_function_props
+        if dynamo_event_source_props is not None:
+            self._values["dynamo_event_source_props"] = dynamo_event_source_props
+        if dynamo_table_props is not None:
+            self._values["dynamo_table_props"] = dynamo_table_props
+        if existing_lambda_obj is not None:
+            self._values["existing_lambda_obj"] = existing_lambda_obj
+        if existing_table_obj is not None:
+            self._values["existing_table_obj"] = existing_table_obj
+        if lambda_function_props is not None:
+            self._values["lambda_function_props"] = lambda_function_props
 
     @builtins.property
     def deploy_lambda(self) -> bool:
@@ -186,16 +244,18 @@ class DynamoDBStreamToLambdaProps():
         default
         :default: - true
         """
-        return self._values.get('deploy_lambda')
+        return self._values.get("deploy_lambda")
 
     @builtins.property
-    def dynamo_event_source_props(self) -> typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]:
+    def dynamo_event_source_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]:
         """Optional user provided props to override the default props.
 
         default
         :default: - Default props are used
         """
-        return self._values.get('dynamo_event_source_props')
+        return self._values.get("dynamo_event_source_props")
 
     @builtins.property
     def dynamo_table_props(self) -> typing.Optional[aws_cdk.aws_dynamodb.TableProps]:
@@ -204,7 +264,7 @@ class DynamoDBStreamToLambdaProps():
         default
         :default: - Default props are used
         """
-        return self._values.get('dynamo_table_props')
+        return self._values.get("dynamo_table_props")
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -215,7 +275,7 @@ class DynamoDBStreamToLambdaProps():
         default
         :default: - None
         """
-        return self._values.get('existing_lambda_obj')
+        return self._values.get("existing_lambda_obj")
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
@@ -224,10 +284,12 @@ class DynamoDBStreamToLambdaProps():
         default
         :default: - None
         """
-        return self._values.get('existing_table_obj')
+        return self._values.get("existing_table_obj")
 
     @builtins.property
-    def lambda_function_props(self) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    def lambda_function_props(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """Optional user provided props to override the default props.
 
         If ``deploy`` is set to true only then this property is required
@@ -235,7 +297,7 @@ class DynamoDBStreamToLambdaProps():
         default
         :default: - Default props are used
         """
-        return self._values.get('lambda_function_props')
+        return self._values.get("lambda_function_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -244,7 +306,9 @@ class DynamoDBStreamToLambdaProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'DynamoDBStreamToLambdaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "DynamoDBStreamToLambdaProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
